==> react-native-ui-view-0.0.6.tgz: package/esm/components/Navbar/index.js <==
import React, { useState } from 'react';
import { StyleSheet, View, Text, StatusBar, TouchableHighlight, } from 'react-native';
import Icon from '../Icon';
import { Theme, FontWeight } from '../Styles/theme';
const Navbar = props => {
    const [left, setLeft] = useState(0);
    const [right, setRight] = useState(0);
    const { height = 42, title, titleSize = 17, titleColor = Theme.colorTextParagraph, titleBold = false, showBack = false, backIconSize = 22, backIconColor = Theme.colorTextParagraph, backIconName = 'left', backText = '', backTextStyle = {}, backgroundColor, barStyle = 'dark-content', showBorderBottom = true, renderLeft, renderRight, onBack, } = props;
    const onLeftLayout = (event) => {
        const { width } = event.nativeEvent.layout;
        setLeft(width);
    };
    const onRightLayout = (event) => {
        const { width } = event.nativeEvent.layout;
        setRight(width);
    };
    const statusBarHeight = StatusBar.currentHeight;
    const offset = Math.max(left, right) + 20;
    const statusBarStyle = {};
    if (backgroundColor) {
        statusBarStyle.backgroundColor = backgroundColor;
    }
    if (showBorderBottom) {
        statusBarStyle.borderBottomColor = Theme.borderColor;
        statusBarStyle.borderBottomWidth = 0.5;
    }
    return (React.createElement(View, { style: statusBarStyle },
        React.createElement(StatusBar, { translucent: true, barStyle: barStyle, backgroundColor: "transparent" }),
        React.createElement(View, { style: { height: statusBarHeight } }),
        React.createElement(View, { style: { ...styles.container, height } },
            renderLeft ? (React.createElement(View, { onLayout: onLeftLayout }, renderLeft())) : (showBack && (React.createElement(TouchableHighlight, { style: styles.backIconWrap, activeOpacity: 0.6, underlayColor: Theme.fillBody, onPress: () => onBack && onBack(), onLayout: onLeftLayout },
                React.createElement(React.Fragment, null,
                    React.createElement(Icon, { name: backIconName, color: backIconColor, size: backIconSize }),
                    !!backText && React.createElement(Text, { style: { ...styles.backText, ...backTextStyle } }, backText))))),
            React.createElement(Text, { style: {
                    ...styles.title,
                    left: offset,
                    right: offset,
                    color: titleColor,
                    fontSize: titleSize,
                    fontWeight: titleBold ? FontWeight.BOLD : FontWeight.NORMAL,
                }, numberOfLines: 1 }, title),
            renderRight && React.createElement(View, { onLayout: onRightLayout }, renderRight()))));
};
const styles = StyleSheet.create({
    container: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        paddingLeft: 6,
        paddingRight: 12,
    },
    backIconWrap: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        padding: 6,
        borderRadius: 40,
    },
    backText: {
        fontSize: 16,
        marginLeft: 2,
        color: Theme.colorTextBase,
    },
    title: {
        flex: 1,
        textAlign: 'center',
        position: 'absolute',
    },
});
export default Navbar;

==> react-native-ui-view-0.0.7.tgz: package/esm/components/Navbar/index.js <==
import React, { useState } from 'react';
import { StyleSheet, View, Text, StatusBar, TouchableHighlight, } from 'react-native';
import Icon from '../Icon';
import { Theme, FONT_WEIGHT } from '../Styles/theme';
const Navbar = props => {
    const [left, setLeft] = useState(0);
    const [right, setRight] = useState(0);
    const { height = 42, title, titleSize = 17, titleColor = Theme.colorTextParagraph, titleBold = false, showBack = false, backIconSize = 22, backIconColor = Theme.colorTextParagraph, backIconName = 'left', backText = '', backTextStyle = {}, backgroundColor, barStyle = 'dark-content', showBorderBottom = true, renderLeft, renderRight, onBack, } = props;
    const onLeftLayout = (event) => {
        const { width } = event.nativeEvent.layout;
        setLeft(width);
    };
    const onRightLayout = (event) => {
        const { width } = event.nativeEvent.layout;
        setRight(width);
    };
    const statusBarHeight = StatusBar.currentHeight;
    const offset = Math.max(left, right) + 15;
    const statusBarStyle = {};
    if (backgroundColor) {
        statusBarStyle.backgroundColor = backgroundColor;
    }
    if (showBorderBottom) {
        statusBarStyle.borderBottomColor = Theme.borderColor;
        statusBarStyle.borderBottomWidth = 0.5;
    }
    return (React.createElement(View, { style: statusBarStyle },
        React.createElement(StatusBar, { translucent: true, barStyle: barStyle, backgroundColor: "transparent" }),
        React.createElement(View, { style: { height: statusBarHeight } }),
        React.createElement(View, { style: { ...styles.container, height } },
            React.createElement(View, { onLayout: onLeftLayout }, renderLeft
                ? renderLeft()
                : showBack && (React.createElement(TouchableHighlight, { style: styles.backIconWrap, activeOpacity: 0.6, underlayColor: Theme.fillBody, onPress: onBack },
                    React.createElement(React.Fragment, null,
                        React.createElement(Icon, { name: backIconName, color: backIconColor, size: backIconSize }),
                        React.createElement(Text, { style: { ...styles.backText, ...backTextStyle } }, backText))))),
            React.createElement(Text, { style: {
                    ...styles.title,
                    left: offset,
                    right: offset,
                    color: titleColor,
                    fontSize: titleSize,
                    fontWeight: titleBold ? FONT_WEIGHT.BOLD : FONT_WEIGHT.NORMAL,
                }, numberOfLines: 1 }, title),
            renderRight && React.createElement(View, { onLayout: onRightLayout }, renderRight()))));
};
const styles = StyleSheet.create({
    container: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        paddingLeft: 6,
        paddingRight: 12,
    },
    backIconWrap: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 8,
        paddingHorizontal: 10,
        borderRadius: 10,
    },
    backText: {
        fontSize: 16,
        marginLeft: 2,
        color: Theme.colorTextBase,
    },
    title: {
        flex: 1,
        textAlign: 'center',
        position: 'absolute',
    },
});
export default Navbar;
